@@ -1,4 +1,4 @@
-//$Id: app-win.cc,v 1.24 2003/12/21 18:03:23 cactus Exp $ -*- c++ -*-
+//$Id: app-win.cc,v 1.24.4.1 2004/08/18 16:42:09 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -75,8 +75,8 @@ namespace
 		return 0;
 
 	    AppPropChangeOp<value_t> *new_op =
-		new AppPropChangeOp<value_t> (label, prop, op->new_val, true);
-	    new_op->old_val = old_val;
+		new AppPropChangeOp<value_t> (this->label, prop, op->new_val, true);
+	    new_op->old_val = this->old_val;
 
 	    return new_op;
 	}
