@@ -1,4 +1,4 @@
-//$Id: form-win.cc,v 1.66 2004/03/23 22:29:23 cactus Exp $ -*- c++ -*-
+//$Id: form-win.cc,v 1.66.2.3 2004/06/08 04:06:18 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -92,16 +92,13 @@ FormWindow::FormWindow (Form *res_):
     Gtk::Tree *tree = wrap (GTK_TREE (glade_xml_get_widget (gui, "form_tree")));
     tree->map_ (); // FIXME: Isn't this evil?
 
-    // Set up zoom factor entry
-    Gtk::Adjustment *zoom_adj = zoom_entry->get_adjustment ();
-    zoom_adj->value_changed.connect (slot (this, &FormWindow::zoom_entry_cb));
-    zoom_adj->set_value (Preferences::FormEditor::get_default_zoom ());
-    
     // Widget tree
     FormWindow_Helpers::TopTreeItem *item = new FormWindow_Helpers::TopTreeItem (res);
     item->show ();
     item->activate.connect (slot (this, &FormWindow::select_form));
     item->menu_edit.connect (slot (this, &FormWindow::select_form));
+    item->menu_select_all.connect (slot (this, &FormWindow::select_all));
+    item->menu_paste.connect (slot (this, &FormWindow::widget_paste_cb));
     tree->add (*manage (item));
     top_treeitem = item;
 
@@ -143,6 +140,10 @@ FormWindow::FormWindow (Form *res_):
 	palette = new Guikachu::GUI::Palette ();
     palette->palette_changed.connect (slot (this, &FormWindow::palette_cb));
 
+    // Set up zoom factor entry
+    Gtk::Adjustment *zoom_adj = zoom_entry->get_adjustment ();
+    zoom_adj->value_changed.connect (slot (this, &FormWindow::zoom_entry_cb));
+    zoom_adj->set_value (Preferences::FormEditor::get_default_zoom ());    
 }
 
 FormWindow::~FormWindow ()
@@ -242,6 +243,7 @@ void FormWindow::target_changed_cb ()
 void FormWindow::zoom_entry_cb ()
 {
     float zoom_factor = zoom_entry->get_value_as_float ();
+
     if (zoom_factor > GNOME_CANVAS_EPSILON)
     {
 	canvas->set_pixels_per_unit (zoom_factor);
@@ -277,8 +279,12 @@ void FormWindow::widget_created_cb (Widget *widget)
     FormWindow_Helpers::WidgetTreeItem *tree_item = new FormWindow_Helpers::WidgetTreeItem (widget);
     tree_item->show ();
     tree_item->activate.connect (bind (slot (this, &FormWindow::select_widget), widget));
+    
+    tree_item->menu_edit.connect   (bind (slot (this, &FormWindow::select_widget), widget));
+    tree_item->menu_cut.connect    (bind (slot (this, &FormWindow::widget_cut_cb), widget));
+    tree_item->menu_copy.connect   (bind (slot (this, &FormWindow::widget_copy_cb), widget));
+    tree_item->menu_paste.connect  (slot (this, &FormWindow::widget_paste_cb));
     tree_item->menu_remove.connect (bind (slot (this, &FormWindow::widget_remove_cb), widget));
-    tree_item->menu_edit.connect (bind (slot (this, &FormWindow::select_widget), widget));
     
     tree->add (*tree_item);
     
@@ -564,9 +570,23 @@ void FormWindow::widget_drag_end_cb (int dx, int dy)
 
 void FormWindow::key_press_cb (GdkEventKey *e)
 {
-    // Del: delete current selection
-    if (e->keyval == GDK_Delete || e->keyval == GDK_KP_Delete)
+    switch (e->keyval)
+    {
+    case GDK_Delete:
+    case GDK_KP_Delete:
 	remove_selection ();
+        break;
+
+    case GDK_Menu:
+        if (selection.size ())
+            widget_menu_cb (3, e->time, last_widget);
+        else
+            form_menu_cb (3, e->time);
+        break;
+        
+    default:
+        break;
+    }
 }
 
 void FormWindow::remove_selection ()
