@@ -1,4 +1,4 @@
-//$Id: rcp-save-form.cc,v 1.13 2004/01/18 21:14:38 cactus Exp $ -*- c++ -*-
+//$Id: rcp-save-form.cc,v 1.13.4.1 2004/06/12 09:08:44 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -17,6 +17,7 @@
  */
 
 #include "rcp-save-form.h"
+#include "rcp-saver-priv.h"
 
 #include "form-editor/label.h"
 #include "form-editor/button.h"
@@ -71,62 +72,64 @@ using namespace Guikachu::IO;
 namespace
 {
 
-void save_element_pos (Widget *widget, std::ostream &ostr)
-{
-    ostr << " AT (" << widget->x << " " << widget->y << ")";
-} 
-
-template<class T>
-void save_element_pos_size (T *res, std::ostream &ostr)
-{
-    ostr << " AT (" << res->x     << " " << res->y      << " "
-         << res->width << " " << res->height << ")" << std::endl;
-}
-
-template<class T>
-void save_element_pos_autosize (T *res, std::ostream &ostr)
-{
-    gchar *width_str = 0, *height_str = 0;
-    
-    if (res->manual_width)
-	width_str = g_strdup_printf ("%d", int (res->width));
-    else
-	width_str = g_strdup ("AUTO");
-    
-    if (res->manual_height)
-	height_str = g_strdup_printf ("%d", int (res->height));
-    else
-	height_str = g_strdup ("AUTO");
-
-    ostr << " AT (" << res->x << " " << res->y
-	 << " " << width_str << " " << height_str << ")";
-
-    g_free (width_str);
-    g_free (height_str);
-}
-
-void save_flag (bool value, std::ostream &ostr,
-                const std::string &true_str,
-                const std::string &false_str = "")
-{
-    if (value)
-	ostr << true_str;
-    else
-	ostr << false_str;
-}
-
-void save_graphical (Widgets::Graphical *widget, std::ostream &ostr)
-{
-    if (widget->bitmap_id != "" || widget->selected_bitmap_id != "")
+    using Guikachu::IO::RCP::operator<<;
+                                       
+    void save_element_pos (Widget *widget, std::ostream &ostr)
     {
-	ostr << " GRAPHICAL";
-	if (widget->bitmap_id != "")
-	    ostr << " BITMAPID " << widget->bitmap_id;
-	if (widget->selected_bitmap_id != "")
-	    ostr << " SELECTEDBITMAPID " << widget->selected_bitmap_id;
-    }    
-}
-
+        ostr << " AT (" << widget->x << " " << widget->y << ")";
+    } 
+    
+    template<class T>
+    void save_element_pos_size (T *res, std::ostream &ostr)
+    {
+        ostr << " AT (" << res->x     << " " << res->y      << " "
+             << res->width << " " << res->height << ")" << std::endl;
+    }
+    
+    template<class T>
+    void save_element_pos_autosize (T *res, std::ostream &ostr)
+    {
+        gchar *width_str = 0, *height_str = 0;
+        
+        if (res->manual_width)
+            width_str = g_strdup_printf ("%d", int (res->width));
+        else
+            width_str = g_strdup ("AUTO");
+        
+        if (res->manual_height)
+            height_str = g_strdup_printf ("%d", int (res->height));
+        else
+            height_str = g_strdup ("AUTO");
+        
+        ostr << " AT (" << res->x << " " << res->y
+             << " " << width_str << " " << height_str << ")";
+        
+        g_free (width_str);
+        g_free (height_str);
+    }
+    
+    void save_flag (bool value, std::ostream &ostr,
+                    const std::string &true_str,
+                    const std::string &false_str = "")
+    {
+        if (value)
+            ostr << true_str;
+        else
+            ostr << false_str;
+    }
+    
+    void save_graphical (Widgets::Graphical *widget, std::ostream &ostr)
+    {
+        if (widget->bitmap_id != "" || widget->selected_bitmap_id != "")
+        {
+            ostr << " GRAPHICAL";
+            if (widget->bitmap_id != "")
+                ostr << " BITMAPID " << widget->bitmap_id;
+            if (widget->selected_bitmap_id != "")
+                ostr << " SELECTEDBITMAPID " << widget->selected_bitmap_id;
+        }    
+    }
+    
 } // Anonymous namespace
     
 void RCPSaver_funcs::save_res_form (Resources::Form *res, std::ostream &ostr)
@@ -268,7 +271,7 @@ void RCP::WidgetSaver::visit_widget (Widgets::List *widget)
     const std::vector<std::string> &items = widget->items;
     for (std::vector<std::string>::const_iterator i = items.begin ();
 	 i != items.end (); i++)
-	ostr << " \"" << escape_backslashes (*i) << "\"";
+	ostr << " \"" << string_to_rcp (*i) << "\"";
     
     ostr << " ID " << widget->id;
     ostr << " AT (" << widget->x << " " << widget->y << " " << width_str << " " << " AUTO)";
