@@ -1,4 +1,4 @@
-//$Id: rcp-saver.h,v 1.3 2004/03/21 17:55:38 cactus Exp $ -*- c++ -*-
+//$Id: rcp-saver.h,v 1.3.4.1 2004/06/12 09:08:45 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -16,8 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#ifndef GUIKACHU_IO_RCP_SAVE_H
-#define GUIKACHU_IO_RCP_SAVE_H
+#ifndef GUIKACHU_IO_RCP_SAVER_H
+#define GUIKACHU_IO_RCP_SAVER_H
 
 #include "io.h"
 
@@ -34,4 +34,4 @@ namespace Guikachu
     }
 }
 
-#endif /* !GUIKACHU_IO_RCP_SAVE_H */
+#endif /* !GUIKACHU_IO_RCP_SAVER_H */
