@@ -1,4 +1,4 @@
-//$Id: mainwin.cc,v 1.49 2004/03/20 23:46:03 cactus Exp $ -*- c++ -*-
+//$Id: mainwin.cc,v 1.49.2.3 2004/06/05 17:22:50 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -173,9 +173,11 @@ void GUI::MainWin::set_manager (ResourceManager *manager_)
 
 void GUI::MainWin::update_recent_files ()
 {
+    std::string insertion_file = dgettext ("gnome-libs", "_File");
+
     // Clear old entries
     if (recent_files_num)
-	remove_menu_range ("File/", 8, recent_files_num + 1);
+	remove_menu_range (insertion_file + '/', 8, recent_files_num + 1);
 
     Preferences::Interface::RecentFiles recent_files =
 	Preferences::Interface::get_recent_files ();
@@ -206,8 +208,8 @@ void GUI::MainWin::update_recent_files ()
 	    g_free (menu_label);
 	}
 
-	insert_menus ("File/Add _Resource...", recent_items);
-	//install_menu_hints ();
+        std::string insertion_res = _("Add _Resource...");
+	insert_menus (insertion_file + '/' + insertion_res, recent_items);
     }
 }
 
@@ -226,7 +228,9 @@ void GUI::MainWin::update_undo ()
     char *undo_label = g_strdup_printf (_("_Undo: %s"), top_undo_label.c_str ());
     char *redo_label = g_strdup_printf (_("_Redo: %s"), top_redo_label.c_str ());
 
-    remove_menu_range ("Edit/", 0, 2);
+    std::string edit_str = dgettext ("gnome-libs", "_Edit");
+    edit_str += '/';
+    remove_menu_range (edit_str, 0, 2);
     
     Gnome::UI::Info undo_items[] = {
 	Gnome::UI::Item (Gnome::UI::Icon (GNOME_STOCK_MENU_UNDO), undo_label,
@@ -238,7 +242,7 @@ void GUI::MainWin::update_undo ()
     g_free (undo_label);
     g_free (redo_label);
     
-    Gnome::UI::Array<Gnome::UI::Info> menubar_widgets = insert_menus ("Edit/", undo_items);
+    Gnome::UI::Array<Gnome::UI::Info> menubar_widgets = insert_menus (edit_str, undo_items);
 
     // Disable menu items if undo and/or redo stack is empty
     menubar_widgets[0].get_widget ()->set_sensitive (undo_labels.size ());
