@@ -1,4 +1,4 @@
-//$Id: menu-win.cc,v 1.33 2004/01/30 01:08:56 cactus Exp $ -*- c++ -*-
+//$Id: menu-win.cc,v 1.33.4.1 2004/05/28 13:20:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -452,7 +452,9 @@ void GUI::MenuWindow::btn_submenu_cb ()
 	submenus.push_back (submenu);
 
 	res->set_submenus (submenus);
-
+        
+        UndoOp *op = new SubmenuCreateOp (res, submenus.size () - 1);
+        res->get_manager ()->get_undo_manager ().push (op);
 	
 	while (Gtk::Main::events_pending ())
 	    Gtk::Main::iteration ();	
